******************
hbp-service-client
******************

Client library for interacting through python with various HBP services.

Currently covered services:

* `document_service.client` : the project/folder/file management service.
